@@ -23,6 +23,7 @@
 
 
 #include "plugin.h"
+#include "libanjuta/anjuta-project.h"
 
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/profiler.xml"
@@ -292,7 +293,7 @@ profiler_set_target (Profiler *profiler, const gchar *profile_target_uri)
 									   _("This target does not have any "
 									     "profiling data.\n\n"
 									     "Please ensure that the target is "
-									     "complied with profiling support "
+									     "compiled with profiling support (-p)"
 										 "and that it is run at least "
 										 "once."));
 		}
@@ -573,7 +574,7 @@ on_profiler_select_target (GtkAction *action, Profiler *profiler)
 													  IAnjutaProjectManager, NULL);
 		
 		exec_targets = ianjuta_project_manager_get_targets (project_manager, 
-							 								IANJUTA_PROJECT_MANAGER_TARGET_EXECUTABLE,
+							 								ANJUTA_TARGET_EXECUTABLE,
 											 				NULL);
 											 				
 		project_root_uri_length = strlen (profiler->project_root_uri) + 1;
@@ -585,13 +586,15 @@ on_profiler_select_target (GtkAction *action, Profiler *profiler)
 			
 			while (current_target)
 			{
-				relative_path = (gchar *) current_target->data + project_root_uri_length;
+				target = g_file_get_uri (G_FILE (current_target->data));
+				relative_path = (gchar *) target + project_root_uri_length;
 				
 				gtk_list_store_append (targets_list_store, &iter);
 				gtk_list_store_set (targets_list_store, &iter, 0, relative_path, 1,
-									current_target->data, -1);
+									target, -1);
 									
-				g_free (current_target->data);
+				g_free (target);
+				g_object_unref (current_target->data);
 				current_target = g_list_next (current_target);
 			}
 			g_list_free (exec_targets);
@@ -624,6 +627,8 @@ on_profiler_select_target (GtkAction *action, Profiler *profiler)
 		}
 		else
 				profiler_set_target (profiler, NULL);
+
+		g_free (target);
 	}
 		
 	gtk_widget_hide (select_target_dialog);
