@@ -25,6 +25,7 @@
 #include <glib/gi18n.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-project.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
@@ -182,7 +183,7 @@ on_menu_run_activate (GtkAction *action, AnjutaValgrindPlugin *plugin)
 			
 	exec_targets =
 		ianjuta_project_manager_get_targets (pm,
-						 IANJUTA_PROJECT_MANAGER_TARGET_EXECUTABLE,
+						 ANJUTA_TARGET_EXECUTABLE,
 						 NULL);
 
 	if (exec_targets) {
@@ -232,12 +233,20 @@ on_menu_run_activate (GtkAction *action, AnjutaValgrindPlugin *plugin)
 		project_root_uri_len = strlen(project_root_uri) + 1;
 	
 		while (node) {
+			GFile *gfile;
 			const gchar *rel_path;
-			rel_path = (gchar*)node->data + project_root_uri_len;
+			gchar *local_path;
+			gfile = node->data;
+
+			local_path = g_file_get_uri (gfile);
+			
+			rel_path = local_path + project_root_uri_len;
 			gtk_list_store_append (store, &iter);
 			gtk_list_store_set (store, &iter, 0, rel_path, 1,
-								node->data, -1);
-			g_free (node->data);
+								local_path, -1);
+			g_free (local_path);
+			g_object_unref (gfile);
+			
 			node = g_list_next (node);
 		}
 		g_list_free (exec_targets);
